---
title: Installing
---

Nēnē is available from [PyPI][pypi] and can be installed with [pip][pip]:

```bash
python -m pip install nene
```

A conda-forge package may come in the future (or maybe not).

[pypi]: https://pypi.org/project/nene/
[pip]: https://github.com/pypa/pip
